@@ -16,12 +16,12 @@ def get_plugin_apps(project_type):
     the INSTALLED_APPS list for the given project_type.
     """
     plugin_apps = [
-        u"{module_name}.{class_name}".format(
+        "{module_name}.{class_name}".format(
             module_name=app_config.__module__, class_name=app_config.__name__,
         )
         for app_config in registry.get_plugin_app_configs(project_type)
         if getattr(app_config, constants.PLUGIN_APP_CLASS_ATTRIBUTE_NAME, None)
         is not None
     ]
-    log.debug(u"Plugin Apps: Found %s", plugin_apps)
+    log.debug("Plugin Apps: Found %s", plugin_apps)
     return plugin_apps
